summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/lib/metaobject.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/macros/lib/metaobject.h')
-rw-r--r--kexi/plugins/macros/lib/metaobject.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kexi/plugins/macros/lib/metaobject.h b/kexi/plugins/macros/lib/metaobject.h
index 8b6115742..a1a52562c 100644
--- a/kexi/plugins/macros/lib/metaobject.h
+++ b/kexi/plugins/macros/lib/metaobject.h
@@ -20,7 +20,7 @@
#ifndef KOMACRO_METAOBJECT_H
#define KOMACRO_METAOBJECT_H
-#include <qobject.h>
+#include <tqobject.h>
#include <ksharedptr.h>
#include "komacro_export.h"
@@ -32,11 +32,11 @@ namespace KoMacro {
class MetaMethod;
/**
* Class to provide abstract access to extended QObject functionality
* like the undocumented QUObject-API in Qt3.
*
- * The design tried to limit future porting to Qt4 by providing a
- * somewhat similar API to the Qt4 QMeta* stuff.
+ * The design tried to limit future porting to TQt4 by providing a
+ * somewhat similar API to the TQt4 TQMeta* stuff.
*/
class KOMACRO_EXPORT MetaObject : public KShared
{
@@ -45,10 +45,10 @@ namespace KoMacro {
/**
* Constructor.
*
* @param object The QObject instance this @a MetaObject provides
* abstract access to.
*/
- explicit MetaObject(QObject* const object);
+ explicit MetaObject(TQObject* const object);
/**
* Destructor.
@@ -56,13 +56,13 @@ namespace KoMacro {
~MetaObject();
/**
* @return the QObject this @a MetaObject provides abstract
* access to.
*/
- QObject* const object() const;
+ TQObject* const object() const;
- //QStrList signalNames() const;
- //QStrList slotNames() const;
+ //TQStrList signalNames() const;
+ //TQStrList slotNames() const;
/**
* @return the index of the signal @p signal .
@@ -91,7 +91,7 @@ namespace KoMacro {
KSharedPtr<MetaMethod> slot(const char* slot);
//KSharedPtr<MetaMethod> addSlot(const char* slot);
-//void connectSignal(QObject* obj, const char* signal);
+//void connectSignal(TQObject* obj, const char* signal);
/**
* Invoke the @a MetaMethod that has the index @p index .
@@ -104,7 +104,7 @@ namespace KoMacro {
* @return The returnvalue the method provides and that got
* returned if the execution is done.
*/
- KSharedPtr<Variable> invokeMethod(int index, QValueList< KSharedPtr<Variable> > arguments);
+ KSharedPtr<Variable> invokeMethod(int index, TQValueList< KSharedPtr<Variable> > arguments);
private:
/// @internal d-pointer class.
@@ -32,11 +32,11 @@ namespace KoMacro {
class MetaMethod;
/**
- * Class to provide abstract access to extended QObject functionality
- * like the undocumented QUObject-API in Qt3.
+ * Class to provide abstract access to extended TQObject functionality
+ * like the undocumented TQUObject-API in TQt3.
*
@@ -45,10 +45,10 @@ namespace KoMacro {
* Constructor.
*
- * @param object The QObject instance this @a MetaObject provides
+ * @param object The TQObject instance this @a MetaObject provides
* abstract access to.
*/
@@ -56,13 +56,13 @@ namespace KoMacro {
~MetaObject();
/**
- * @return the QObject this @a MetaObject provides abstract
+ * @return the TQObject this @a MetaObject provides abstract
* access to.
*/